.. splinebox documentation master file, created by
   sphinx-quickstart on Tue Feb 20 16:01:44 2024.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to splinebox's documentation!
=====================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   basis_functions
   spline_curves
   auto_examples/index.rst

.. math::
   f(x) = \sum_{k=0}^{M-1} c[k]\phi(x-k)


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
